/*
 * Copyright 2021 - 2022 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.sbm.engine.recipe;

import org.openrewrite.SourceFile;
import org.springframework.sbm.project.resource.ProjectResourceSet;
import org.springframework.sbm.project.resource.RewriteSourceFileHolder;
import org.springframework.sbm.project.resource.filter.ProjectResourceFinder;

import java.util.List;
import java.util.stream.Collectors;

public class OpenRewriteSourceFilesFinder implements ProjectResourceFinder<List<SourceFile>> {

    public List<SourceFile> apply(ProjectResourceSet projectResourceSet) {
        return projectResourceSet.stream()
                .filter(RewriteSourceFileHolder.class::isInstance)
                .map(RewriteSourceFileHolder.class::cast)
                .filter(pr -> SourceFile.class.isAssignableFrom(pr.getType()))
                .map(RewriteSourceFileHolder::getSourceFile)
                .map(SourceFile.class::cast)
                .collect(Collectors.toList());
    }
}
